@@ -3,13 +3,14 @@ from qm_spider import *
 
 
 class Send_Mail:
-    def __init__(self, subject, mail_text, file_path, send_user, send_userpwd, receivers=('ctrlf4@yeah.net')):
+    def __init__(self, subject, mail_text, file_path, send_user, send_userpwd, receivers=('ctrlf4@yeah.net'), cc=()):
         self.subject = subject
         self.mail_text = mail_text
         self.file_path = file_path
         self.receivers = receivers
         self.send_user = send_user
         self.send_userpwd = send_userpwd
+        self.cc = cc
 
     def send_qm_mail(self):
         self.mail_content = {
@@ -24,5 +25,8 @@ class Send_Mail:
         else:
             server = zmail.server(self.send_user, self.send_userpwd)
 
-        server.send_mail(self.receivers, self.mail_content)
+        if len(self.cc) > 0:
+            server.send_mail(self.receivers, self.mail_content, cc=self.cc)
+        else:
+            server.send_mail(self.receivers, self.mail_content)
         return '%s-发送成功' %(self.subject)
\ No newline at end of file
